**To delete a ledger**

The following ``delete-ledger`` example deletes the specified ledger. ::

    aws qldb delete-ledger \
        --name myExampleLedger

This command produces no output.

For more information, see `Basic Operations for Amazon QLDB Ledgers <https://docs.aws.amazon.com/qldb/latest/developerguide/ledger-management.basics.html>`__ in the *Amazon QLDB Developer Guide*.
